@@ -21,7 +21,7 @@ npscoef <-
   }
 
 npscoef.formula <-
-  function(bws, data = NULL, newdata = NULL, ...){
+  function(bws, data = NULL, newdata = NULL, y.eval = FALSE, ...){
 
     tt <- terms(bws)
     m <- match(c("formula", "data", "subset", "na.action"),
@@ -37,24 +37,45 @@ npscoef.formula <-
       tzdat <- tmf[, bws$chromoly[[3]], drop = FALSE]
 
     if ((has.eval <- !is.null(newdata))) {
-      if (!(has.ey <- succeedWithResponse(tt, newdata)))
+      if (!y.eval){
         tt <- delete.response(tt)
 
+        orig.class <- sapply(eval(attr(tt, "variables"), newdata, environment(tt)),class)
+        
+        ## delete.response clobbers predvars, which is used for timeseries objects
+        ## so we need to reconstruct it
+
+        if(all(orig.class == "ts")){
+          args <- (as.list(attr(tt, "variables"))[-1])
+          attr(tt, "predvars") <- as.call(c(quote(as.data.frame),as.call(c(quote(ts.intersect), args))))
+        }else if(any(orig.class == "ts")){
+          arguments <- (as.list(attr(tt, "variables"))[-1])
+          arguments.normal <- arguments[which(orig.class != "ts")]
+          arguments.timeseries <- arguments[which(orig.class == "ts")]
+
+          ix <- sort(c(which(orig.class == "ts"),which(orig.class != "ts")),index.return = TRUE)$ix
+          attr(tt, "predvars") <- bquote(.(as.call(c(quote(cbind),as.call(c(quote(as.data.frame),as.call(c(quote(ts.intersect), arguments.timeseries)))),arguments.normal,check.rows = TRUE)))[,.(ix)])
+        }else{
+          attr(tt, "predvars") <- attr(tt, "variables")
+        }
+      }
+      
       umf <- emf <- model.frame(tt, data = newdata)
 
-      if (has.ey)
+      if (y.eval)
         eydat <- model.response(emf)
-
+      
       exdat <- emf[, bws$chromoly[[2]], drop = FALSE]
       if (!miss.z)
         ezdat <- emf[, bws$chromoly[[3]], drop = FALSE]
     }
 
+
     ev <-
       eval(parse(text=paste("npscoef(txdat = txdat, tydat = tydat,",
                    ifelse(miss.z, '','tzdat = tzdat,'),
                    ifelse(has.eval,paste("exdat = exdat,",
-                                         ifelse(has.ey,"eydat = eydat,",""),
+                                         ifelse(y.eval,"eydat = eydat,",""),
                                          ifelse(miss.z,'', 'ezdat = ezdat,')),""),
                    "bws = bws, ...)")))
 
@@ -102,8 +123,8 @@ npscoef.default <- function(bws, txdat, tydat, tzdat, ...) {
   if(txdat.named)
     txdat <- toFrame(txdat)
 
-  if(tydat.named)
-    tydat <- toFrame(tydat)
+  ## if(tydat.named)
+  ## tydat <- toFrame(tydat)
 
   if(tydat.named)
     tzdat <- toFrame(tzdat)
@@ -314,7 +335,7 @@ npscoef.scbandwidth <-
 
     tww <- eval(parse(text=paste("npksum(txdat = tzdat, tydat = yW, weights = yW,",
                     ifelse(miss.ex, "", "exdat = ezdat,"),
-                    "bws = bws)$ksum")))
+                    "bws = bws, leave.one.out = leave.one.out)$ksum")))
 
     tyw <- tww[-1,1,,drop=FALSE]
     dim(tyw) <- dim(tyw)[-2]
@@ -413,7 +434,8 @@ npscoef.scbandwidth <-
       tywtm <- npksum(txdat = tzdat,
                       tydat = yW,
                       weights = yW,
-                      bws = bws)$ksum
+                      bws = bws,
+                      leave.one.out = leave.one.out)$ksum
 
       tyw <- tywtm[-1,1,]
       tm <- tywtm[-1,-1,]
@@ -458,7 +480,7 @@ npscoef.scbandwidth <-
       u2.W <- t(u2.W)
 
       V.hat <- eval(parse(text = paste("npksum(txdat = tzdat, tydat = W.train, weights = u2.W,",
-                            ifelse(!miss.ex, "exdat = ezdat,", ""), "bws = bws)$ksum")))
+                            ifelse(!miss.ex, "exdat = ezdat,", ""), "bws = bws, leave.one.out = leave.one.out)$ksum")))
 
       ## asymptotics rely on positive definite nature of tww (ie. M.eval) and V.hat
       ## so choleski decomposition is used to assure their veracity
